Structs

A straight-forward binary format that encodes numeric values in fixed width.

Constants

Traits

Functions

Deserialize a Thrift blob using the binary protocol.
Serialize a Thrift value using the binary protocol.
How large an item will be when serialize() is called
Serialize a Thrift value using the binary protocol to a pre-allocated buffer. This will panic if the buffer is not large enough. A buffer at least as large as the return value of serialize_size will not panic.