pub struct BinaryProtocol<F = Bytes>;
A straight-forward binary format that encodes numeric values in fixed width.

let protocol = BinaryProtocol;
let transport = HttpClient::new(ENDPOINT)?;
let client = <dyn BuckGraphService>::new(protocol, transport);

The type parameter is the Framing expected by the transport on which this protocol is operating. Usually by convention the transport itself serves as the Framing impl, so for example in the case of HttpClient above, the compiler has inferred F = HttpClient.

Where the compiler reports that a Framing can’t be inferred, one can be specified explicitly:

let protocol = BinaryProtocol::<SRHeaderTransport>;