Type Definition fbthrift_git::framing::FramingEncodedFinal
source · Expand description
Helper type alias to get the type of the finalized encoded buffer
Helper type alias to get the type of the finalized encoded buffer