☰
Module processor
Structs
Enums
Traits
?
Module
fbthrift_git
::
processor
source
·
[
−
]
Structs
NullServiceProcessor
Null processor which implements no methods - it acts as the super for any service which has no super-service.
Enums
SerializedStreamElement
Traits
ReplyState
ServiceProcessor
Trait implemented by a generated type to implement a service.
ThriftService