Structs
Constants
- DEFAULT_
RECURSION_ DEPTH - The maximum recursive depth the skip() function will traverse
Traits
- Protocol
- An instance of Protocol glues a Framing implementation to a serializer (ProtocolWriter) and deserializer (ProtocolReader). It constructs, as needed, a serializer to construct a frame with a given protocol, or a deserializer from a frame into a stream of deserialized objects.
- Protocol
Reader - Trait for decoding a frame in a given protocol
- Protocol
Writer - Trait for emitting a frame formatted in a given protocol
Functions
Type Aliases
- Protocol
Decoded - Helper type alias to get the buffer type for a frame to be decoded.
- Protocol
Encoded - Helper type alias to get the pre-finalization encoded type of a protocol frame.
- Protocol
Encoded Final - Helper type alias to get the final encoded type of a protocol frame